@@ -9,15 +9,14 @@
 
 #include <modemmanagerqt_export.h>
 
+#include <QDBusObjectPath>
 #include <QObject>
 #include <QSharedPointer>
-#include <QDBusObjectPath>
 
 #include "generictypes.h"
 
 namespace ModemManager
 {
-
 class InterfacePrivate;
 
 class MODEMMANAGERQT_EXPORT Interface : public QObject
@@ -32,7 +31,7 @@ public:
 
     explicit Interface(const QString &path, QObject *parent = nullptr);
     explicit Interface(InterfacePrivate &dd, QObject *parent = nullptr);
-    virtual ~Interface();
+    ~Interface() override;
 
     QString uni() const;
 
